You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by mt...@apache.org on 2011/05/12 16:17:57 UTC

svn commit: r1102322 - /commons/sandbox/runtime/trunk/src/main/test/org/apache/commons/runtime/TestAddress.java

Author: mturk
Date: Thu May 12 14:17:57 2011
New Revision: 1102322

URL: http://svn.apache.org/viewvc?rev=1102322&view=rev
Log:
Check for well known service

Modified:
    commons/sandbox/runtime/trunk/src/main/test/org/apache/commons/runtime/TestAddress.java

Modified: commons/sandbox/runtime/trunk/src/main/test/org/apache/commons/runtime/TestAddress.java
URL: http://svn.apache.org/viewvc/commons/sandbox/runtime/trunk/src/main/test/org/apache/commons/runtime/TestAddress.java?rev=1102322&r1=1102321&r2=1102322&view=diff
==============================================================================
--- commons/sandbox/runtime/trunk/src/main/test/org/apache/commons/runtime/TestAddress.java (original)
+++ commons/sandbox/runtime/trunk/src/main/test/org/apache/commons/runtime/TestAddress.java Thu May 12 14:17:57 2011
@@ -54,10 +54,10 @@ public class TestAddress extends Assert
         throws IOException
     {
         // XXX: It works only for lowercase names.
         //      Eg. "Http" will fail with EAGAIN.
         //
-        Service s1 = new Service("http", "tcp");
-        assertEquals(s1.getPort(), 80);
+        Service s1 = new Service("discard", "tcp");
+        assertEquals(s1.getPort(), 9);
         assertNotNull(s1.getAliases());
         Service s2 = new Service(21);
         assertEquals(s2.getName(), "ftp");
@@ -54,10 +54,10 @@ public class TestAddress extends Assert
     {
         // XXX: It works only for lowercase names.
-        //      Eg. "Http" will fail with EAGAIN.
+        //      Eg. "Discard" will fail with EAGAIN.
         //